@@ -33,11 +33,12 @@ class CountrySelect(forms.Select):
             if isinstance(option_label, (list, tuple)):
                 opt_val = ""
                 from upy.fields import CONTINENTS
+
                 for el in CONTINENTS:
                     if option_value == u"{}".format(el[1]):
                         opt_val = el[0]
                 output.append(format_html('<optgroup label="{0}" class="{1}">',
-                                          force_text(option_value),force_text(opt_val)))
+                                          force_text(option_value), force_text(opt_val)))
                 for option in option_label:
                     output.append(self.render_option(selected_choices, *option))
                 output.append('</optgroup>')
@@ -47,7 +48,6 @@ class CountrySelect(forms.Select):
 
 
 class NullCheckboxWidget(forms.CheckboxInput):
-    
     def render(self, name, value, attrs=None):
         final_attrs = self.build_attrs(attrs, type='checkbox', name=name)
         try:
@@ -68,7 +68,7 @@ class NullCheckboxWidget(forms.CheckboxInput):
             return False
         value = data.get(name)
         # Translate true and false strings to boolean values.
-        values =  {'on': True, 'false': False}
+        values = {'on': True, 'false': False}
         if isinstance(value, basestring):
             value = values.get(value.lower(), value)
         return value
@@ -90,10 +90,12 @@ class SubFKWidget(forms.Select):
     refer_id: represents css id of object needs add button
     calling: represents object that calls createAddButton
     """
-    def __init__(self,sub_options = [],refer_id = '',calling = '', *args, **kwargs):
+
+    def __init__(self, sub_options=[], refer_id='', calling='', *args, **kwargs):
         """
         Takes following parameters:
-        sub_options: is a list of dictionaries. Each dictionary has application (lower application's name), model (lower model's name), html (html for add popup link),
+        sub_options: is a list of dictionaries. Each dictionary has application (lower application's name),
+                     model (lower model's name), html (html for add popup link),
         refer_id: represents css id of object needs add button,
         calling: represents object that calls createAddButton
         """
@@ -119,15 +121,19 @@ class SubFKWidget(forms.Select):
             application = item['application']
             model = item['model']
             html = item['html']
-            buttons += '<span class = "add_custom_button"><a href="/admin/'+application+'/'+model+'/add/" class="add-another" id="add_'+self.refer_id+'" onclick="return showAddAnotherPopupCustom(this,\''+self.calling+'\');">'+html+'</a></span>';
+            buttons += '<span class = "add_custom_button"><a href="/admin/' + application + '/' + model \
+                       + '/add/" class="add-another" id="add_' + self.refer_id \
+                       + '" onclick="return showAddAnotherPopupCustom(this,\'' + self.calling + '\');">' \
+                       + html + '</a></span>';
         return buttons
-    
+
     def validate_sub_options(self):
         """
         Validates sub_options parameter
         """
         if not self.sub_options or self.sub_options == []:
-            raise ValueError("Error in upy.widgets.SubFKWidget: sub_options can't be empty or none. Check configurations in model")
+            raise ValueError(
+                "Error in upy.widgets.SubFKWidget: sub_options can't be empty or none. Check configurations in model")
         for item in self.sub_options:
             if not item.has_key('application'):
                 raise ValueError("Error in upy.widgets.SubFKWidget: missing argument 'application' in sub_options")
@@ -135,8 +141,8 @@ class SubFKWidget(forms.Select):
                 raise ValueError("Error in upy.widgets.SubFKWidget: missing argument 'model' in sub_options")
             if not item.has_key('html'):
                 raise ValueError("Error in upy.widgets.SubFKWidget: missing argument 'html' in sub_options")
-    
+
     class Media:
         js = (settings.JQUERY_LIB,
               '/upy_static/js/sub_foreignkey.js',)
-        css = {"all" : ("/upy_static/css/sub_foreignkey.css",)}
\ No newline at end of file
+        css = {"all": ("/upy_static/css/sub_foreignkey.css",)}
\ No newline at end of file
